@@ -3,13 +3,14 @@ package Time::Beat;
 # Module to use the new Swatch Internet time.
 
 use strict;
-use vars qw ( $VERSION @ISA @EXPORT );
+use vars qw ( $VERSION @EXPORT_OK );
 
-$VERSION = '1.00';
+$VERSION = '1.02';
 
 use Exporter;
-@ISA    = qw ( Exporter );
-@EXPORT = qw ( beattime );
+
+use base qw ( Exporter );
+@EXPORT_OK = qw ( beattime );
 
 sub beattime {
 	my $time = shift || time();
@@ -18,7 +19,9 @@ sub beattime {
 	my ($sec, $min, $hour, $mday, $mon, $year, $yday, $isdst) =
 		gmtime($time);
 
-	$hsecs = (($hour + 1) * 60) * 60;	
+	if ($hour != 23) {
+  	  $hsecs = (($hour + 1) * 60) * 60;	
+	}
 	$hsecs += ($min * 60);
 	$hsecs += $sec;
 	return sprintf("%i", $hsecs / 86.4);
@@ -36,7 +39,7 @@ Time::Beat - Module to convert from standard time to swatch 'beat' time.
 
 =head1 SYNOPSIS
 
-use Time::Beat;
+use Time::Beat qw ( beattime );
 
 my $time_in_beats = beattime(time());
 
@@ -60,9 +63,14 @@ specify a time string it will return that particular time in beats.
 
 =back
 
-=head1 BUGS
+=head1 CHANGES
 
-James A. Duncan <jduncan@hawk.igs.net>
+If gmtime.hours == 23 before then problems were caused because the hour became 24 - it should have been 0.  The problem has
+now been fixed.
+
+=head1 AUTHOR
+
+James A. Duncan <j@mesduncan.co.uk>
 
 =head1 SEE ALSO
 
